@@ -31,19 +31,20 @@ System (version for POSIX threads).
 #include "gnome-vfs-job.h"
 
 #include "gnome-vfs-async-job-map.h"
+#include "gnome-vfs-job-slave.h"
 #include "gnome-vfs-job-queue.h"
-#include "gnome-vfs-private-utils.h"
 #include <errno.h>
+#include <fcntl.h>
 #include <glib/gmessages.h>
 #include <glib/gstrfuncs.h>
-#include <glib/gi18n-lib.h>
 #include <libgnomevfs/gnome-vfs-cancellable-ops.h>
 #include <libgnomevfs/gnome-vfs-context.h>
+#include <libgnomevfs/gnome-vfs-i18n.h>
 #include <libgnomevfs/gnome-vfs-backend.h>
 #include <string.h>
 #include <unistd.h>
 
-static GStaticPrivate job_private = G_STATIC_PRIVATE_INIT;
+GStaticPrivate job_private = G_STATIC_PRIVATE_INIT;
 
 #if GNOME_VFS_JOB_DEBUG
 
@@ -51,7 +52,7 @@ char *job_debug_types[] = {
 	"open", "open as channel",
 	"create", "create symbolic link",
 	"create as channel", "close",
-	"read", "write", "seek", "read write done",
+	"read", "write", "read write done",
 	"load directory", "find directory",
 	"xfer", "get file info", "set file info",
 	"module callback", "file control",
@@ -77,6 +78,46 @@ static gboolean dispatch_sync_job_callback          (gpointer              data)
 static void	clear_current_job 		    (void);
 static void	set_current_job 		    (GnomeVFSJob *context);
 
+static void
+set_fl (int fd, int flags)
+{
+	int val;
+
+	val = fcntl (fd, F_GETFL, 0);
+	if (val < 0) {
+		g_warning ("fcntl() F_GETFL failed: %s", strerror (errno));
+		return;
+	}
+
+	val |= flags;
+	
+	val = fcntl (fd, F_SETFL, val);
+	if (val < 0) {
+		g_warning ("fcntl() F_SETFL failed: %s", strerror (errno));
+		return;
+	}
+}
+
+static void
+clr_fl (int fd, int flags)
+{
+	int val;
+
+	val = fcntl (fd, F_GETFL, 0);
+	if (val < 0) {
+		g_warning ("fcntl() F_GETFL failed: %s", strerror (errno));
+		return;
+	}
+
+	val &= ~flags;
+	
+	val = fcntl (fd, F_SETFL, val);
+	if (val < 0) {
+		g_warning ("fcntl() F_SETFL failed: %s", strerror (errno));
+		return;
+	}
+}
+
 /*
  *   Find out whether or not a given job should be left in
  * the job map, preserving it's open VFS handle, since we
@@ -102,7 +143,6 @@ _gnome_vfs_job_complete (GnomeVFSJob *job)
 		return FALSE;
 	case GNOME_VFS_OP_READ_WRITE_DONE:
 	case GNOME_VFS_OP_FILE_CONTROL:
-	case GNOME_VFS_OP_SEEK:
 		return FALSE;
 	
 	default:
@@ -127,8 +167,6 @@ job_oneway_notify (GnomeVFSJob *job, GnomeVFSNotifyResult *notify_result)
 		JOB_DEBUG (("Barfing on oneway cancel %u (%d) type '%s'",
 			    GPOINTER_TO_UINT (notify_result->job_handle),
 			    job->op->type, JOB_DEBUG_TYPE (job->op->type)));
-		/* TODO: We can leak handle here, if an open succeded.
-		 * See bug #123472 */
 		_gnome_vfs_job_destroy_notify_result (notify_result);
 	}
 }
@@ -222,14 +260,6 @@ dispatch_write_callback (GnomeVFSNotifyResult *notify_result)
 						     notify_result->specifics.write.callback_data);
 }
 
-static void
-dispatch_seek_callback (GnomeVFSNotifyResult *notify_result)
-{
-	(* notify_result->specifics.seek.callback) (notify_result->job_handle,
-						    notify_result->specifics.seek.result,
-						    notify_result->specifics.seek.callback_data);
-}
-
 static void
 dispatch_load_directory_callback (GnomeVFSNotifyResult *notify_result)
 {
@@ -366,7 +396,6 @@ _gnome_vfs_job_destroy_notify_result (GnomeVFSNotifyResult *notify_result)
 	case GNOME_VFS_OP_CREATE_AS_CHANNEL:
 	case GNOME_VFS_OP_CREATE_SYMBOLIC_LINK:
 	case GNOME_VFS_OP_WRITE:
-	case GNOME_VFS_OP_SEEK:
 	case GNOME_VFS_OP_OPEN:
 	case GNOME_VFS_OP_OPEN_AS_CHANNEL:
 	case GNOME_VFS_OP_READ:
@@ -575,9 +604,6 @@ dispatch_job_callback (gpointer data)
 	case GNOME_VFS_OP_WRITE:
 		dispatch_write_callback (notify_result);
 		break;
-	case GNOME_VFS_OP_SEEK:
-		dispatch_seek_callback (notify_result);
-		break;
 	case GNOME_VFS_OP_FILE_CONTROL:
 		dispatch_file_control_callback (notify_result);
 		break;
@@ -722,7 +748,6 @@ gnome_vfs_op_destroy (GnomeVFSOp *op)
 		break;
 	case GNOME_VFS_OP_READ:
 	case GNOME_VFS_OP_WRITE:
-	case GNOME_VFS_OP_SEEK:
 	case GNOME_VFS_OP_CLOSE:
 	case GNOME_VFS_OP_READ_WRITE_DONE:
 		break;
@@ -730,7 +755,7 @@ gnome_vfs_op_destroy (GnomeVFSOp *op)
 		g_free (op->specifics.file_control.operation);
 		break;
 	default:
-		g_warning (_("Unknown operation type %u"), op->type);
+		g_warning (_("Unknown op type %u"), op->type);
 	}
 	
 	g_assert (gnome_vfs_context_get_cancellation (op->context) != NULL);
@@ -846,7 +871,7 @@ serve_channel_read (GnomeVFSHandle *handle,
 
 					fd = g_io_channel_unix_get_fd (channel_out);
 					
-					_gnome_vfs_pipe_set_blocking (fd, TRUE);
+					clr_fl (fd, O_NONBLOCK);
 				} else {
 					if (written_bytes_in_buffer > 0) {
 						/* Need to shift the unwritten bytes
@@ -912,7 +937,7 @@ serve_channel_write (GnomeVFSHandle *handle,
 
 		io_result = g_io_channel_read_chars (channel_in, buffer, buffer_size,
 						     &bytes_read, NULL);
-                
+
 		if (io_result == G_IO_STATUS_AGAIN)
 			continue;
 		if (io_result != G_IO_STATUS_NORMAL || bytes_read == 0)
@@ -1018,9 +1043,8 @@ execute_open_as_channel (GnomeVFSJob *job)
 		job_oneway_notify (job, notify_result);
 		return;
 	}
-	
 
-	if (_gnome_vfs_pipe (pipefd) < 0) {
+	if (pipe (pipefd) < 0) {
 		g_warning (_("Cannot create pipe for open GIOChannel: %s"),
 			   g_strerror (errno));
 		notify_result->specifics.open_as_channel.result = GNOME_VFS_ERROR_INTERNAL;
@@ -1034,15 +1058,11 @@ execute_open_as_channel (GnomeVFSJob *job)
 	 * thread is blocking for some reason the slave can keep
 	 * reading data.
 	 */
-	_gnome_vfs_pipe_set_blocking (pipefd[1], FALSE);
+	set_fl (pipefd[1], O_NONBLOCK);
 	
-#ifndef G_OS_WIN32
 	channel_in = g_io_channel_unix_new (pipefd[0]);
 	channel_out = g_io_channel_unix_new (pipefd[1]);
-#else
-	channel_in = g_io_channel_win32_new_socket (pipefd[0]);
-	channel_out = g_io_channel_win32_new_socket (pipefd[1]);
-#endif
+
 	open_mode = open_as_channel_op->open_mode;
 	
 	if (open_mode & GNOME_VFS_OPEN_READ) {
@@ -1148,12 +1168,10 @@ execute_create_as_channel (GnomeVFSJob *job)
 	if (create_as_channel_op->uri == NULL) {
 		result = GNOME_VFS_ERROR_INVALID_URI;
 	} else {
-		result = gnome_vfs_create_uri_cancellable
+		result = gnome_vfs_open_uri_cancellable
 			(&handle,
 			 create_as_channel_op->uri,
 			 create_as_channel_op->open_mode,
-                         create_as_channel_op->exclusive,
-                         create_as_channel_op->perm,
 			 job->op->context);
 	}
 	
@@ -1171,7 +1189,7 @@ execute_create_as_channel (GnomeVFSJob *job)
 		return;
 	}
 
-	if (_gnome_vfs_pipe (pipefd) < 0) {
+	if (pipe (pipefd) < 0) {
 		g_warning (_("Cannot create pipe for open GIOChannel: %s"),
 			   g_strerror (errno));
 		notify_result->specifics.create_as_channel.result = GNOME_VFS_ERROR_INTERNAL;
@@ -1181,13 +1199,8 @@ execute_create_as_channel (GnomeVFSJob *job)
 		return;
 	}
 	
-#ifndef G_OS_WIN32
 	channel_in = g_io_channel_unix_new (pipefd[0]);
 	channel_out = g_io_channel_unix_new (pipefd[1]);
-#else
-	channel_in = g_io_channel_win32_new_socket (pipefd[0]);
-	channel_out = g_io_channel_win32_new_socket (pipefd[1]);
-#endif
 
 	notify_result->specifics.create_as_channel.channel = channel_out;
 
@@ -1269,30 +1282,6 @@ execute_write (GnomeVFSJob *job)
 	job_oneway_notify (job, notify_result);
 }
 
-static void
-execute_seek (GnomeVFSJob *job)
-{
-	GnomeVFSResult result;
-	GnomeVFSSeekOp *seek_op;
-	GnomeVFSNotifyResult *notify_result;
-
-	seek_op = &job->op->specifics.seek;
-
-	result = gnome_vfs_seek_cancellable (job->handle,
-					     seek_op->whence,
-					     seek_op->offset,
-					     job->op->context);
-
-	notify_result = g_new0 (GnomeVFSNotifyResult, 1);
-	notify_result->job_handle = job->job_handle;
-	notify_result->type = job->op->type;
-	notify_result->specifics.seek.result = result;
-	notify_result->specifics.seek.callback = (GnomeVFSAsyncSeekCallback) job->op->callback;
-	notify_result->specifics.seek.callback_data = job->op->callback_data;
-
-	job_oneway_notify (job, notify_result);
-}
-
 static void
 execute_get_file_info (GnomeVFSJob *job)
 {
@@ -1673,9 +1662,6 @@ _gnome_vfs_job_execute (GnomeVFSJob *job)
 		case GNOME_VFS_OP_WRITE:
 			execute_write (job);
 			break;
-		case GNOME_VFS_OP_SEEK:
-			execute_seek (job);
-			break;
 		case GNOME_VFS_OP_LOAD_DIRECTORY:
 			execute_load_directory (job);
 			break;
